{ pkgs, config, ... }:
{
  boot = {
    # nixos-hardware use latest kernel by default. It has been set a while ago, we maybe don't need it anymore?
    kernelPackages = pkgs.linuxPackages;

    # Otherwise it will not show stage1 echo and prompt
    # UPST
    kernelParams = [ "console=tty0" ];

    # Pinebook supports UEFI, at least when tow-boot is installed on the SPI
    loader = {
      # EFI Variables don't work (no generation appears in systemd-boot)
      efi.canTouchEfiVariables = false;
      grub.efiInstallAsRemovable = true;
    };
  };

  frogeye.desktop = {
    x11_screens = [ "DP-1" "eDP-1" ];
    maxVideoHeight = 720;
    phasesBrightness = {
      enable = true;
      jour = "3500";
      crepuscule = "3000";
      nuit = "700";
    };
  };

  zramSwap = {
    # Not capable of building itself otherwise
    enable = true;
    memoryPercent = 150; # Factory settings
  };

  # Fixes black font on Alacritty
  environment.variables.PAN_MESA_DEBUG = "gl3";
}
